==> linux-2.3.4.tar.bz2: linux/drivers/usb/keymap.c <==
unsigned char usb_kbd_map[256] = 
{
    0x00,  0x00,  0x00,  0x00,  0x1e,  0x30,  0x2e,  0x20,
    0x12,  0x21,  0x22,  0x23,  0x17,  0x24,  0x25,  0x26,

    0x32,  0x31,  0x18,  0x19,  0x10,  0x13,  0x1f,  0x14,
    0x16,  0x2f,  0x11,  0x2d,  0x15,  0x2c,  0x02,  0x03,

    0x04,  0x05,  0x06,  0x07,  0x08,  0x09,  0x0a,  0x0b,
    0x1c,  0x01,  0x0e,  0x0f,  0x39,  0x0c,  0x0d,  0x1a,

    0x1b,  0x2b,  0x00,  0x27,  0x28,  0x29,  0x33,  0x34,
    0x35,  0x3a,  0x3b,  0x3c,  0x3d,  0x3e,  0x3f,  0x40,

    0x41,  0x42,  0x43,  0x44,  0x57,  0x58,  0xb7,  0x46,
    0x00,  0xd2,  0xc7,  0xc9,  0xd3,  0xcf,  0xd1,  0xcd,

    0xcb,  0xd0,  0xc8,  0x45,  0xb5,  0x37,  0x4a,  0x4e,
    0x9c,  0x4f,  0x50,  0x51,  0x4b,  0x4c,  0x4d,  0x47,

    0x48,  0x49,  0x52,  0x53,  0x00,  0x6d,  0x00,  0x00,
    0xbd,  0xbe,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,

    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,
    0x1d,  0x2a,  0x38,  0xdb,  0x9d,  0x36,  0xb8,  0xdc,

    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,
    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,

    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,
    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,

    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,
    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,

    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,
    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,

    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,
    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,

    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,
    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,

    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,
    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,

    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,
    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,
};

==> linux-2.3.35.tar.bz2: linux/drivers/usb/keymap.c <==
unsigned char usb_kbd_map[256] = 
{
    0x00,  0x00,  0x00,  0x00,  0x1e,  0x30,  0x2e,  0x20,
    0x12,  0x21,  0x22,  0x23,  0x17,  0x24,  0x25,  0x26,

    0x32,  0x31,  0x18,  0x19,  0x10,  0x13,  0x1f,  0x14,
    0x16,  0x2f,  0x11,  0x2d,  0x15,  0x2c,  0x02,  0x03,

    0x04,  0x05,  0x06,  0x07,  0x08,  0x09,  0x0a,  0x0b,
    0x1c,  0x01,  0x0e,  0x0f,  0x39,  0x0c,  0x0d,  0x1a,

    0x1b,  0x2b,  0x2b,  0x27,  0x28,  0x29,  0x33,  0x34,
    0x35,  0x3a,  0x3b,  0x3c,  0x3d,  0x3e,  0x3f,  0x40,

    0x41,  0x42,  0x43,  0x44,  0x57,  0x58,  0xb7,  0x46,
    0x00,  0xd2,  0xc7,  0xc9,  0xd3,  0xcf,  0xd1,  0xcd,

    0xcb,  0xd0,  0xc8,  0x45,  0xb5,  0x37,  0x4a,  0x4e,
    0x9c,  0x4f,  0x50,  0x51,  0x4b,  0x4c,  0x4d,  0x47,

    0x48,  0x49,  0x52,  0x53,  0x56,  0x6d,  0x00,  0x00,
    0xbd,  0xbe,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,

    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,
    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,

    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,
    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,

    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,
    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,

    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,
    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,

    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,
    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,

    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,
    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,

    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,
    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,

    0x1d,  0x2a,  0x38,  0xdb,  0x9d,  0x36,  0xb8,  0xdc,
    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,

    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,
    0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,  0x00,
};
